<?php

	/**
	 * Japanese language file for phpPgAdmin.
	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
	 *
	 * $Id: japanese.php,v 1.17.2.1 2007/01/19 04:27:10 xzilla Exp $
	 */

	// Language and character set
	$lang['applang'] = '&#26085;&#26412;&#35486;(EUC-JP)';
	$lang['appcharset'] = 'EUC-JP';
	$lang['applocale'] = 'ja_JP';
  	$lang['appdbencoding'] = 'EUC_JP';
	$lang['applangdir'] = 'ltr';
  
	// Welcome  
	$lang['strintro'] = '&#12424;&#12358;&#12371;&#12381; phpPgAdmin &#12408;&#12290;';
	$lang['strppahome'] = 'phpPgAdmin &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
	$lang['strpgsqlhome'] = 'PostgreSQL &#12507;&#12540;&#12512;&#12506;&#12540;&#12472;';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL &#12489;&#12461;&#12517;&#12513;&#12531;&#12488; (&#12525;&#12540;&#12459;&#12523;)';
	$lang['strreportbug'] = '&#12496;&#12464;&#12524;&#12509;&#12540;&#12488;';
	$lang['strviewfaq'] = 'FAQ &#12434;&#35211;&#12427;';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = '&#12525;&#12464;&#12452;&#12531;';
	$lang['strloginfailed'] = '&#12525;&#12464;&#12452;&#12531;&#12395;&#22833;&#25943;';
	$lang['strlogindisallowed'] = '&#12525;&#12464;&#12452;&#12531;&#12364;&#35377;&#21487;&#12373;&#12428;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
	$lang['strserver'] = '&#12469;&#12540;&#12496;&#12540;';
	$lang['strservers'] = '&#12469;&#12540;&#12496;&#12540;';
	$lang['strintroduction'] = '&#23566;&#20837;';
	$lang['strhost'] = '&#12507;&#12473;&#12488;';
	$lang['strport'] = '&#12509;&#12540;&#12488;';
	$lang['strlogout'] = '&#12525;&#12464;&#12450;&#12454;&#12488;';
	$lang['strowner'] = '&#25152;&#26377;&#32773;';
	$lang['straction'] = '&#12450;&#12463;&#12471;&#12519;&#12531;';
	$lang['stractions'] = '&#25805;&#20316;';
	$lang['strname'] = '&#21517;&#21069;';
	$lang['strdefinition'] = '&#23450;&#32681;';
	$lang['strproperties'] = '&#12503;&#12525;&#12497;&#12486;&#12451;';
	$lang['strbrowse'] = '&#34920;&#31034;';
	$lang['strdrop'] = '&#30772;&#26820;';
	$lang['strdropped'] = '&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strnull'] = 'NULL';
	$lang['strnotnull'] = 'NOT NULL';
	$lang['strprev'] = '&#21069;&#12395;';
	$lang['strnext'] = '&#27425;&#12395;';
	$lang['strfirst'] = '&lt;&lt; &#26368;&#21021;';
	$lang['strlast'] = '&#26368;&#24460; &gt;&gt;';
	$lang['strfailed'] = '&#22833;&#25943;';
	$lang['strcreate'] = '&#20316;&#25104;';
	$lang['strcreated'] = '&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcomment'] = '&#12467;&#12513;&#12531;&#12488;';
	$lang['strlength'] = '&#38263;&#12373;';
	$lang['strdefault'] = '&#12487;&#12501;&#12457;&#12523;&#12488;';
	$lang['stralter'] = '&#22793;&#26356;';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = '&#21462;&#12426;&#28040;&#12375;';
	$lang['strsave'] = '&#20445;&#23384;';
	$lang['strreset'] = '&#12522;&#12475;&#12483;&#12488;';
	$lang['strinsert'] = '&#25407;&#20837;';
	$lang['strselect'] = '&#36984;&#25246;';
	$lang['strdelete'] = '&#21066;&#38500;';
	$lang['strupdate'] = '&#26356;&#26032;';
	$lang['strreferences'] = '&#21442;&#29031;';
	$lang['stryes'] = '&#12399;&#12356;';
	$lang['strno'] = '&#12356;&#12356;&#12360;';
	$lang['strtrue'] = '&#30495;';
	$lang['strfalse'] = '&#20605;';
	$lang['stredit'] = '&#32232;&#38598;';
	$lang['strcolumn'] = '&#12459;&#12521;&#12512;';
	$lang['strcolumns'] = '&#12459;&#12521;&#12512;';
	$lang['strrows'] = '&#12524;&#12467;&#12540;&#12489;';
	$lang['strrowsaff'] = '&#24433;&#38911;&#12434;&#21463;&#12369;&#12383;&#12524;&#12467;&#12540;&#12489;';
	$lang['strobjects'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;';
	$lang['strback'] = '&#25147;&#12427;';
	$lang['strqueryresults'] = '&#12463;&#12456;&#12522;&#32080;&#26524;';
	$lang['strshow'] = '&#34920;&#31034;';
	$lang['strempty'] = '&#31354;&#12395;&#12377;&#12427;';
	$lang['strlanguage'] = '&#35328;&#35486;';
	$lang['strencoding'] = '&#12456;&#12531;&#12467;&#12540;&#12489;';
	$lang['strvalue'] = '&#20516;';
	$lang['strunique'] = '&#12518;&#12491;&#12540;&#12463;';
	$lang['strprimary'] = '&#12503;&#12521;&#12452;&#12510;&#12522;';
	$lang['strexport'] = '&#12456;&#12463;&#12473;&#12509;&#12540;&#12488;';
	$lang['strimport'] = '&#12452;&#12531;&#12509;&#12540;&#12488;';
	$lang['strallowednulls']  =  'NULL &#25991;&#23383;&#12434;&#35377;&#21487;&#12377;&#12427;';
	$lang['strbackslashn']  =  '\N';
	$lang['strnull']  =  'Null';
	$lang['stremptystring']  =  '&#31354;&#12398;&#25991;&#23383;&#21015;/&#38917;&#30446;';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = '&#31649;&#29702;';
	$lang['strvacuum'] = '&#12496;&#12461;&#12517;&#12540;&#12512;';
	$lang['stranalyze'] = '&#35299;&#26512;';
	$lang['strclusterindex']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;';
$lang['strclustered'] = 'Clustered?';
	$lang['strreindex'] = '&#20877;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
	$lang['strrun'] = '&#23455;&#12459;&#12521;&#12512;';
	$lang['stradd'] = '&#36861;&#21152;';
	$lang['strremove']  =  '&#21066;&#38500;';
	$lang['strevent'] = '&#12452;&#12505;&#12531;&#12488;';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = '&#20195;&#34892;';
	$lang['strwhen'] = 'When';
	$lang['strformat'] = '&#12501;&#12457;&#12540;&#12510;&#12483;&#12488;';
	$lang['strdata'] = '&#12487;&#12540;&#12479;';
	$lang['strconfirm'] = '&#30906;&#35469;';
	$lang['strexpression'] = '&#35413;&#20385;&#24335;';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = '&#23637;&#38283;';
	$lang['strcollapse'] = '&#38281;&#12376;&#12427;';
	$lang['strexplain'] = '&#23455;&#34892;&#26178;&#38291;';
	$lang['strexplainanalyze'] = '&#35443;&#32048;&#20986;&#21147;&#35299;&#26512;';
	$lang['strfind'] = '&#26908;&#32034;';
	$lang['stroptions'] = '&#12458;&#12503;&#12471;&#12519;&#12531;';
	$lang['strrefresh'] = '&#20877;&#34920;&#31034;';
	$lang['strdownload'] = '&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
	$lang['strdownloadgzipped'] = 'gzip &#12391;&#22311;&#32302;&#12375;&#12390;&#12480;&#12454;&#12531;&#12525;&#12540;&#12489;';
	$lang['strinfo'] = '&#24773;&#22577;';
	$lang['stroids'] = 'OID ';
	$lang['stradvanced'] = '&#39640;&#24230;&#12394;';
	$lang['strvariables'] = '&#22793;&#25968;';
	$lang['strprocess'] = '&#12503;&#12525;&#12475;&#12473;';
	$lang['strprocesses'] = '&#12503;&#12525;&#12475;&#12473;';
	$lang['strsetting'] = '&#35373;&#23450;';
	$lang['streditsql'] = 'SQL &#32232;&#38598;';
	$lang['strruntime'] = '&#32207;&#23455;&#34892;&#26178;&#38291;: %s &#12511;&#12522;&#31186;';
	$lang['strpaginate'] = 'Paginate results';
	$lang['struploadscript'] = '&#12414;&#12383;&#12399; SQL &#12473;&#12463;&#12522;&#12503;&#12488;&#12434;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;:';
	$lang['strstarttime'] = '&#38283;&#22987;&#26178;&#38291;';
	$lang['strfile'] = '&#12501;&#12449;&#12452;&#12523;';
	$lang['strfileimported'] = '&#12501;&#12449;&#12452;&#12523;&#12434;&#12452;&#12531;&#12509;&#12540;&#12488;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtrycred']  =  '&#12377;&#12409;&#12390;&#12398;&#12469;&#12540;&#12496;&#12540;&#12391;&#12371;&#12398;&#24773;&#22577;&#12434;&#20351;&#12358;';

	// Database Sizes
$lang['strsize']  =  '&#12469;&#12452;&#12474;';
$lang['strbytes']  =  '&#12496;&#12452;&#12488;';
$lang['strkb']  =  'kB';
$lang['strmb']  =  'MB';
$lang['strgb']  =  'GB';
$lang['strtb']  =  'TB';

	// Error handling
	$lang['strnoframes'] = '&#12371;&#12398;&#12450;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12434;&#20351;&#29992;&#12377;&#12427;&#12383;&#12417;&#12395;&#12399;&#12501;&#12524;&#12540;&#12512;&#12364;&#20351;&#29992;&#21487;&#33021;&#12394;&#12502;&#12521;&#12454;&#12470;&#12540;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
	$lang['strnoframeslink'] = '&#12501;&#12524;&#12540;&#12512;&#12434;&#38500;&#22806;&#12375;&#12390;&#20351;&#12358;';
	$lang['strbadconfig'] = 'config.inc.php &#12364;&#26087;&#24335;&#12391;&#12377;&#12290;&#26032;&#12375;&#12356; config.inc.php-dist &#12363;&#12425;&#20877;&#20316;&#25104;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strnotloaded'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#12469;&#12509;&#12540;&#12488;&#12377;&#12427;&#12424;&#12358;&#12395; PHP &#12398;&#12467;&#12531;&#12497;&#12452;&#12523;&#12539;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12364;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;configure &#12398; --with-pgsql &#12458;&#12503;&#12471;&#12519;&#12531;&#12434;&#29992;&#12356;&#12390; PHP &#12434;&#20877;&#12467;&#12531;&#12497;&#12452;&#12523;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strpostgresqlversionnotsupported'] = '&#12371;&#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12398; PostgreSQL &#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
	$lang['strbadschema'] = '&#28961;&#21177;&#12398;&#12473;&#12461;&#12540;&#12510;&#12364;&#25351;&#23450;&#12373;&#12428;&#12414;&#12375;&#12383;&#12290;';
	$lang['strbadencoding'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#20013;&#12391;&#12463;&#12521;&#12452;&#12450;&#12531;&#12488;&#12456;&#12531;&#12467;&#12540;&#12489;&#12434;&#25351;&#23450;&#12375;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
	$lang['strsqlerror'] = 'SQL &#12456;&#12521;&#12540;:';
	$lang['strinstatement'] = '&#25991;:';
	$lang['strinvalidparam'] = '&#12473;&#12463;&#12522;&#12503;&#12488;&#12497;&#12521;&#12513;&#12540;&#12479;&#12364;&#28961;&#21177;&#12391;&#12377;&#12290;';
	$lang['strnodata'] = '&#12524;&#12467;&#12540;&#12489;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnoobjects'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strrownotunique'] = '&#12371;&#12398;&#12524;&#12467;&#12540;&#12489;&#12395;&#12399;&#19968;&#24847;&#35672;&#21029;&#23376;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnoreportsdb'] = '&#12524;&#12509;&#12540;&#12488;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20316;&#25104;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12395;&#12354;&#12427; INSTALL &#12501;&#12449;&#12452;&#12523;&#12434;&#35501;&#12435;&#12391;&#12367;&#12384;&#12373;&#12356;&#12290;';
	$lang['strnouploads'] = '&#12501;&#12449;&#12452;&#12523;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;&#12364;&#28961;&#21177;&#12391;&#12377;&#12290;';
	$lang['strimporterror'] = '&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;';
	$lang['strimporterror-fileformat']  =  '&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;: &#12501;&#12449;&#12452;&#12523;&#24418;&#24335;&#12434;&#33258;&#21205;&#30340;&#12395;&#30906;&#23450;&#12391;&#12365;&#12414;&#12379;&#12435;&#12290;.';
	$lang['strimporterrorline'] = '%s &#34892;&#30446;&#12364;&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;&#12391;&#12377;&#12290;';
	$lang['strimporterrorline-badcolumnnum']  =  '%s &#34892;&#12391;&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;:  &#34892;&#12399;&#27491;&#12375;&#12356;&#21015;&#25968;&#12434;&#25345;&#12387;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;';
	$lang['strimporterror-uploadedfile']  =  '&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;: &#12469;&#12540;&#12496;&#12540;&#12395;&#12501;&#12449;&#12452;&#12523;&#12434;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;&#12377;&#12427;&#12371;&#12392;&#12364;&#12391;&#12365;&#12394;&#12356;&#12363;&#12418;&#12375;&#12428;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcannotdumponwindows']  =  'Windows &#19978;&#12391;&#12398;&#35079;&#21512;&#12486;&#12540;&#12502;&#12523;&#12392;&#12473;&#12461;&#12540;&#12510;&#21517;&#12398;&#12480;&#12531;&#12503;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;';

	// Tables
	$lang['strtable'] = '&#12486;&#12540;&#12502;&#12523;';
	$lang['strtables'] = '&#12486;&#12540;&#12502;&#12523;';
	$lang['strshowalltables'] = '&#20840;&#12486;&#12540;&#12502;&#12523;&#12434;&#35211;&#12427;';
	$lang['strnotables'] = '&#12486;&#12540;&#12502;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnotable'] = '&#12486;&#12540;&#12502;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatetable'] = '&#12486;&#12540;&#12502;&#12523;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strtablename'] = '&#12486;&#12540;&#12502;&#12523;&#21517;';
	$lang['strtableneedsname'] = '&#12486;&#12540;&#12502;&#12523;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strtableneedsfield'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12388;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtableneedscols'] = '&#26377;&#21177;&#12394;&#12459;&#12521;&#12512;&#25968;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtablecreated'] = '&#12486;&#12540;&#12502;&#12523;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablecreatedbad'] = '&#12486;&#12540;&#12502;&#12523;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroptable'] = '&#12486;&#12540;&#12502;&#12523;&#12300;%s&#12301;&#12434;&#26412;&#24403;&#12395;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtabledropped'] = '&#12486;&#12540;&#12502;&#12523;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtabledroppedbad'] = '&#12486;&#12540;&#12502;&#12523;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfemptytable'] = '&#26412;&#24403;&#12395;&#12486;&#12540;&#12502;&#12523;&#12300;%s&#12301;&#12398;&#20869;&#23481;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtableemptied'] = '&#12486;&#12540;&#12502;&#12523;&#12364;&#31354;&#12395;&#12394;&#12426;&#12414;&#12375;&#12383;.';
	$lang['strtableemptiedbad'] = '&#12486;&#12540;&#12502;&#12523;&#12434;&#31354;&#12395;&#12391;&#12365;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
	$lang['strinsertrow'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#25407;&#20837;';
	$lang['strrowinserted'] = '&#12524;&#12467;&#12540;&#12489;&#12434;&#25407;&#20837;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrowinsertedbad'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#25407;&#20837;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrowduplicate']  =  '&#12524;&#12467;&#12540;&#12489;&#12398;&#25407;&#20837;&#12395;&#22833;&#25943;&#12375;&#12289;&#25407;&#20837;&#12398;&#35079;&#35069;&#12434;&#35430;&#12415;&#12414;&#12375;&#12383;&#12290;';
	$lang['streditrow'] = '&#12524;&#12467;&#12540;&#12489;&#32232;&#38598;';
	$lang['strrowupdated'] = '&#12524;&#12467;&#12540;&#12489;&#12434;&#26356;&#26032;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrowupdatedbad'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdeleterow'] = '&#12524;&#12467;&#12540;&#12489;&#21066;&#38500;';
	$lang['strconfdeleterow'] = '&#26412;&#24403;&#12395;&#12371;&#12398;&#12524;&#12467;&#12540;&#12489;&#12434;&#21066;&#38500;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strrowdeleted'] = '&#12524;&#12467;&#12540;&#12489;&#12434;&#21066;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrowdeletedbad'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strinsertandrepeat'] = '&#25407;&#20837;&#12392;&#32368;&#12426;&#36820;&#12375;';
	$lang['strnumcols'] = '&#12459;&#12521;&#12512;&#12398;&#25968;';
	$lang['strcolneedsname'] = '&#12459;&#12521;&#12512;&#12398;&#21517;&#21069;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strselectallfields'] = '&#12377;&#12409;&#12390;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#36984;&#25246;&#12377;&#12427;';
	$lang['strselectneedscol'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12399;&#24517;&#35201;&#12391;&#12377;&#12290;';
	$lang['strselectunary'] = '&#21336;&#38917;&#12398;&#12458;&#12506;&#12524;&#12540;&#12479;&#12540;&#12399;&#20516;&#12434;&#25345;&#12388;&#12371;&#12392;&#12364;&#12391;&#12365;&#12414;&#12379;&#12435;&#12290;';
	$lang['straltercolumn'] = '&#12459;&#12521;&#12512;&#12398;&#22793;&#26356;';
	$lang['strcolumnaltered'] = '&#12459;&#12521;&#12512;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcolumnalteredbad'] = '&#12459;&#12521;&#12512;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropcolumn'] = '&#26412;&#24403;&#12395;&#12459;&#12521;&#12512;&#12300;%s&#12301;&#12434;&#12486;&#12540;&#12502;&#12523;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12390;&#12356;&#12356;&#12391;&#12377;&#12363;?';
	$lang['strcolumndropped'] = '&#12459;&#12521;&#12512;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcolumndroppedbad'] = '&#12459;&#12521;&#12512;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['straddcolumn'] = '&#12459;&#12521;&#12512;&#12398;&#36861;&#21152;';
	$lang['strcolumnadded'] = '&#12459;&#12521;&#12512;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcolumnaddedbad'] = '&#12459;&#12521;&#12512;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcascade'] = '&#12459;&#12473;&#12465;&#12540;&#12489;';
	$lang['strtablealtered'] = '&#12486;&#12540;&#12502;&#12523;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablealteredbad'] = '&#12486;&#12540;&#12502;&#12523;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdataonly'] = '&#12487;&#12540;&#12479;&#12398;&#12415;';
	$lang['strstructureonly'] = '&#27083;&#36896;&#12398;&#12415;';
	$lang['strstructureanddata'] = '&#27083;&#36896;&#12392;&#12487;&#12540;&#12479;';
	$lang['strtabbed'] = '&#12479;&#12502;&#21306;&#20999;&#12426;';
	$lang['strauto'] = '&#33258;&#21205;';
	$lang['strconfvacuumtable'] = '&#26412;&#24403;&#12395;&#12300;%s&#12301;&#12434;&#12496;&#12461;&#12517;&#12540;&#12512;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strestimatedrowcount'] = '&#35413;&#20385;&#28168;&#12524;&#12467;&#12540;&#12489;&#25968;';

	// Users
	$lang['struser'] = '&#12518;&#12540;&#12470;&#12540;';
	$lang['strusers'] = '&#12518;&#12540;&#12470;&#12540;';
	$lang['strusername'] = '&#12518;&#12540;&#12470;&#12540;&#21517;';
	$lang['strpassword'] = '&#12497;&#12473;&#12527;&#12540;&#12489;';
	$lang['strsuper'] = '&#12473;&#12540;&#12497;&#12540;&#12518;&#12540;&#12470;&#12540;&#12391;&#12377;&#12363;?';
	$lang['strcreatedb'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strexpires'] = '&#26377;&#21177;&#26399;&#38480;';
	$lang['strsessiondefaults'] = '&#12475;&#12483;&#12471;&#12519;&#12531;&#12487;&#12501;&#12457;&#12523;&#12488;';
	$lang['strnousers'] = '&#12518;&#12540;&#12470;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['struserupdated'] = '&#12518;&#12540;&#12470;&#12540;&#12434;&#26356;&#26032;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['struserupdatedbad'] = '&#12518;&#12540;&#12470;&#12540;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strshowallusers'] = '&#20840;&#12390;&#12398;&#12518;&#12540;&#12470;&#12540;&#12434;&#35211;&#12427;&#12290;';
	$lang['strcreateuser'] = '&#12518;&#12540;&#12470;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['struserneedsname'] = '&#12518;&#12540;&#12470;&#12540;&#12398;&#21517;&#21069;&#12434;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
	$lang['strusercreated'] = '&#12518;&#12540;&#12470;&#12540;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strusercreatedbad'] = '&#12518;&#12540;&#12470;&#12540;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropuser'] = '&#26412;&#24403;&#12395;&#12518;&#12540;&#12470;&#12540;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['struserdropped'] = '&#12518;&#12540;&#12470;&#12540;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['struserdroppedbad'] = '&#12518;&#12540;&#12470;&#12540;&#12398;&#21066;&#38500;&#12395;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;';
	$lang['straccount'] = '&#12450;&#12459;&#12454;&#12531;&#12488;';
	$lang['strchangepassword'] = '&#12497;&#12473;&#12527;&#12540;&#12489;&#22793;&#26356;';
	$lang['strpasswordchanged'] = '&#12497;&#12473;&#12527;&#12540;&#12489;&#12398;&#22793;&#26356;&#12434;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strpasswordchangedbad'] = '&#12497;&#12473;&#12527;&#12540;&#12489;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strpasswordshort'] = '&#12497;&#12473;&#12527;&#12540;&#12489;&#12364;&#30701;&#12377;&#12366;&#12414;&#12377;&#12290;';
	$lang['strpasswordconfirm'] = '&#12497;&#12473;&#12527;&#12540;&#12489;&#12398;&#30906;&#35469;&#12364;&#19968;&#33268;&#12375;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
		
	// Groups
	$lang['strgroup'] = '&#12464;&#12523;&#12540;&#12503;';
	$lang['strgroups'] = '&#12464;&#12523;&#12540;&#12503;';
	$lang['strnogroup'] = '&#12464;&#12523;&#12540;&#12503;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnogroups'] = '&#12464;&#12523;&#12540;&#12503;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreategroup'] = '&#12464;&#12523;&#12540;&#12503;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strshowallgroups'] = '&#20840;&#12464;&#12523;&#12540;&#12503;&#12434;&#35211;&#12427;';
	$lang['strgroupneedsname'] = '&#12464;&#12523;&#12540;&#12503;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strgroupcreated'] = '&#12464;&#12523;&#12540;&#12503;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strgroupcreatedbad'] = '&#12464;&#12523;&#12540;&#12503;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';	
	$lang['strconfdropgroup'] = '&#26412;&#24403;&#12395;&#12464;&#12523;&#12540;&#12503;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strgroupdropped'] = '&#12464;&#12523;&#12540;&#12503;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strgroupdroppedbad'] = '&#12464;&#12523;&#12540;&#12503;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strmembers'] = '&#12513;&#12531;&#12496;&#12540;';
	$lang['straddmember'] = '&#12513;&#12531;&#12496;&#12540;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strmemberadded'] = '&#12513;&#12531;&#12496;&#12540;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strmemberaddedbad'] = '&#12513;&#12531;&#12496;&#12540;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdropmember'] = '&#12513;&#12531;&#12496;&#12540;&#30772;&#26820;';
	$lang['strconfdropmember'] = '&#26412;&#24403;&#12395;&#12513;&#12531;&#12496;&#12540;&#12300;%s&#12301;&#12434;&#12464;&#12523;&#12540;&#12503;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strmemberdropped'] = '&#12513;&#12531;&#12496;&#12540;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strmemberdroppedbad'] = '&#12513;&#12531;&#12496;&#12540;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Privileges
	$lang['strprivilege'] = '&#29305;&#27177;';
	$lang['strprivileges'] = '&#29305;&#27177;';
	$lang['strnoprivileges'] = '&#12371;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12399;&#29305;&#27177;&#12434;&#25345;&#12387;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;';
	$lang['strgrant'] = '&#27177;&#38480;';
	$lang['strrevoke'] = '&#24259;&#27490;';
	$lang['strgranted'] = '&#29305;&#27177;&#12434;&#19982;&#12360;&#12414;&#12375;&#12383;&#12290;';
	$lang['strgrantfailed'] = '&#29305;&#27177;&#12434;&#19982;&#12360;&#12427;&#20107;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strgrantbad'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#20154;&#12398;&#12518;&#12540;&#12470;&#12540;&#12363;&#12464;&#12523;&#12540;&#12503;&#12395;&#12289;&#23569;&#12394;&#12367;&#12392;&#12418;&#12402;&#12392;&#12388;&#12398;&#29305;&#27177;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strgrantor'] = '&#35698;&#19982;';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;';
	$lang['strdatabases'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;';
	$lang['strshowalldatabases'] = '&#20840;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#35211;&#12427;';
	$lang['strnodatabase'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnodatabases'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20840;&#12367;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatedatabase'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strdatabasename'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#21517;';
	$lang['strdatabaseneedsname'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strdatabasecreated'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdatabasecreatedbad'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';	
	$lang['strconfdropdatabase'] = '&#26412;&#24403;&#12395;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strdatabasedropped'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdatabasedroppedbad'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strentersql'] = '&#19979;&#12395;&#23455;&#34892;&#12377;&#12427;SQL&#12434;&#20837;&#21147;&#12375;&#12414;&#12377;:';
	$lang['strsqlexecuted'] = 'SQL&#12434;&#23455;&#34892;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strvacuumgood'] = '&#12496;&#12461;&#12517;&#12540;&#12512;&#12434;&#23436;&#20102;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strvacuumbad'] = '&#12496;&#12461;&#12517;&#12540;&#12512;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['stranalyzegood'] = '&#35299;&#26512;&#12434;&#23436;&#20102;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['stranalyzebad'] = '&#35299;&#26512;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strreindexgood'] = '&#20877;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#23436;&#20102;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strreindexbad'] = '&#20877;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfull'] = '&#12377;&#12409;&#12390;';
	$lang['strfreeze'] = '&#12501;&#12522;&#12540;&#12474;';
	$lang['strforce'] = '&#24375;&#21046;';
	$lang['strsignalsent'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;';
	$lang['strsignalsentbad'] = '&#12471;&#12464;&#12490;&#12523;&#36865;&#20449;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;';
	$lang['strallobjects'] = '&#12377;&#12409;&#12390;&#12398;&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;';
	$lang['strdatabasealtered']  =  '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdatabasealteredbad']  =  '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Views
	$lang['strview'] = '&#12499;&#12517;&#12540;';
	$lang['strviews'] = '&#12499;&#12517;&#12540;';
	$lang['strshowallviews'] = '&#20840;&#12499;&#12517;&#12540;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnoview'] = '&#12499;&#12517;&#12540;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnoviews'] = '&#12499;&#12517;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateview'] = '&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strviewname'] = '&#12499;&#12517;&#12540;&#21517;';
	$lang['strviewneedsname'] = '&#12499;&#12517;&#12540;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strviewneedsdef'] = '&#23450;&#32681;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strviewneedsfields'] = '&#12499;&#12517;&#12540;&#12398;&#12398;&#20013;&#12363;&#12425;&#36984;&#25246;&#12375;&#12289;&#24076;&#26395;&#12398;&#12459;&#12521;&#12512;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strviewcreated'] = '&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strviewcreatedbad'] = '&#12499;&#12517;&#12540;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropview'] = '&#26412;&#24403;&#12395;&#12499;&#12517;&#12540;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strviewdropped'] = '&#12499;&#12517;&#12540;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strviewdroppedbad'] = '&#12499;&#12517;&#12540;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strviewupdated'] = '&#12499;&#12517;&#12540;&#12434;&#26356;&#26032;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strviewupdatedbad'] = '&#12499;&#12517;&#12540;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
$lang['strviewlink'] = 'Linking Keys';
	$lang['strviewconditions'] = '&#36861;&#21152;&#26465;&#20214;';
	$lang['strcreateviewwiz'] = '&#12454;&#12451;&#12470;&#12540;&#12489;&#12391;&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';

	// Sequences
	$lang['strsequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;';
	$lang['strsequences'] = '&#12471;&#12540;&#12465;&#12531;&#12473;';
	$lang['strshowallsequences'] = '&#20840;&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#35211;&#12427;';
	$lang['strnosequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnosequences'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatesequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strlastvalue'] = '&#26368;&#32066;&#20516;';
	$lang['strincrementby'] = '&#22679;&#21152;&#25968;';	
	$lang['strstartvalue'] = '&#38283;&#22987;&#20516;';
	$lang['strmaxvalue'] = '&#26368;&#22823;&#20516;';
	$lang['strminvalue'] = '&#26368;&#23567;&#20516;';
	$lang['strcachevalue'] = '&#12461;&#12515;&#12483;&#12471;&#12517;&#20516;';
	$lang['strlogcount'] = '&#12525;&#12464;&#12459;&#12454;&#12531;&#12488;';
	$lang['striscycled'] = 'Cycle &#12375;&#12414;&#12377;&#12363;?';
$lang['striscalled'] = 'Is Called?';
	$lang['strsequenceneedsname'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strsequencecreated'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequencecreatedbad'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;'; 
	$lang['strconfdropsequence'] = '&#26412;&#24403;&#12395;&#12471;&#12540;&#12465;&#12531;&#12473;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strsequencedropped'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequencedroppedbad'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequencereset'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12522;&#12475;&#12483;&#12488;&#12434;&#34892;&#12356;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequenceresetbad'] = '&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#12522;&#12475;&#12483;&#12488;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;'; 

	// Indexes
	$lang['strindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
	$lang['strindexes'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
	$lang['strindexname'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#21517;';
	$lang['strshowallindexes'] = '&#20840;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnoindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnoindexes'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateindex'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strtabname'] = '&#12479;&#12502;&#21517;';
	$lang['strcolumnname'] = '&#12459;&#12521;&#12512;&#21517;';
	$lang['strindexneedsname'] = '&#26377;&#21177;&#12394;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;';
	$lang['strindexneedscols'] = '&#26377;&#21177;&#12394;&#12459;&#12521;&#12512;&#25968;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12356;&#12369;&#12414;&#12379;&#12435;&#12290;';
	$lang['strindexcreated'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strindexcreatedbad'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropindex'] = '&#26412;&#24403;&#12395;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strindexdropped'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strindexdroppedbad'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strkeyname'] = '&#12461;&#12540;&#21517;';
	$lang['struniquekey'] = '&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;';
	$lang['strprimarykey'] = '&#12503;&#12521;&#12452;&#12510;&#12522;&#12461;&#12540;';
 	$lang['strindextype'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12479;&#12452;&#12503;';
	$lang['strtablecolumnlist'] = '&#12486;&#12540;&#12502;&#12523;&#20013;&#12398;&#12459;&#12521;&#12512;';
	$lang['strindexcolumnlist'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#20013;&#12398;&#12459;&#12521;&#12512;';
	$lang['strconfcluster'] = '&#26412;&#24403;&#12395;&#12300;%s&#12301;&#12434;&#12463;&#12521;&#12473;&#12479;&#12540;&#12395;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strclusteredgood'] = '&#12463;&#12521;&#12473;&#12479;&#12540;&#23436;&#20102;&#12391;&#12377;&#12290;';
	$lang['strclusteredbad'] = '&#12463;&#12521;&#12473;&#12479;&#12540;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Rules
	$lang['strrules'] = '&#12523;&#12540;&#12523;';
	$lang['strrule'] = '&#12523;&#12540;&#12523;';
	$lang['strshowallrules'] = '&#20840;&#12523;&#12540;&#12523;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnorule'] = '&#12523;&#12540;&#12523;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnorules'] = '&#12523;&#12540;&#12523;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreaterule'] = '&#12523;&#12540;&#12523;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strrulename'] = '&#12523;&#12540;&#12523;&#21517;';
	$lang['strruleneedsname'] = '&#12523;&#12540;&#12523;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strrulecreated'] = '&#12523;&#12540;&#12523;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrulecreatedbad'] = '&#12523;&#12540;&#12523;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroprule'] = '&#26412;&#24403;&#12395;&#12523;&#12540;&#12523;&#12300;%s&#12301;&#12434;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strruledropped'] = '&#12523;&#12540;&#12523;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strruledroppedbad'] = '&#12523;&#12540;&#12523;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Constraints
	$lang['strconstraint'] = '&#26908;&#26619;&#21046;&#32004;';
	$lang['strconstraints'] = '&#26908;&#26619;&#21046;&#32004;';
	$lang['strshowallconstraints'] = '&#20840;&#26908;&#26619;&#21046;&#32004;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnoconstraints'] = '&#26908;&#26619;&#21046;&#32004;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateconstraint'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strconstraintcreated'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconstraintcreatedbad'] = '&#26908;&#26619;&#21046;&#32004;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropconstraint'] = '&#26412;&#24403;&#12395;&#26908;&#26619;&#21046;&#32004;&#12300;%s&#12301;&#12434;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strconstraintdropped'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconstraintdroppedbad'] = '&#26908;&#26619;&#21046;&#32004;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['straddcheck'] = '&#26908;&#26619;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strcheckneedsdefinition'] = '&#26908;&#26619;&#21046;&#32004;&#12395;&#12399;&#23450;&#32681;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
	$lang['strcheckadded'] = '&#26908;&#26619;&#21046;&#32004;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strcheckaddedbad'] = '&#26908;&#26619;&#21046;&#32004;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['straddpk'] = '&#12503;&#12521;&#12452;&#12510;&#12522;&#12461;&#12540;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strpkneedscols'] = '&#12503;&#12521;&#12452;&#12510;&#12522;&#12461;&#12540;&#12399;&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12434;&#24517;&#35201;&#12392;&#12375;&#12414;&#12377;&#12290;';
	$lang['strpkadded'] = '&#12503;&#12521;&#12452;&#12510;&#12522;&#12461;&#12540;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strpkaddedbad'] = '&#12503;&#12521;&#12452;&#12510;&#12522;&#12461;&#12540;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['stradduniq'] = '&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['struniqneedscols'] = '&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;&#12399;&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12434;&#24517;&#35201;&#12392;&#12375;&#12414;&#12377;&#12290;';
	$lang['struniqadded'] = '&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['struniqaddedbad'] = '&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['straddfk'] = '&#22806;&#37096;&#12461;&#12540;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strfkneedscols'] = '&#22806;&#37096;&#12461;&#12540;&#12399;&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#12459;&#12521;&#12512;&#12434;&#24517;&#35201;&#12392;&#12375;&#12414;&#12377;&#12290;';
	$lang['strfkneedstarget'] = '&#22806;&#37096;&#12461;&#12540;&#12399;&#12479;&#12540;&#12466;&#12483;&#12488;&#12486;&#12540;&#12502;&#12523;&#12434;&#24517;&#35201;&#12392;&#12375;&#12414;&#12377;&#12290;';
	$lang['strfkadded'] = '&#22806;&#37096;&#12461;&#12540;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfkaddedbad'] = '&#22806;&#37096;&#12461;&#12540;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfktarget'] = '&#23550;&#35937;&#12486;&#12540;&#12502;&#12523;';
	$lang['strfkcolumnlist'] = '&#12461;&#12540;&#20013;&#12398;&#12459;&#12521;&#12512;';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';	

	// Functions
	$lang['strfunction'] = '&#38306;&#25968;';
	$lang['strfunctions'] = '&#38306;&#25968;';
	$lang['strshowallfunctions'] = '&#20840;&#38306;&#25968;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnofunction'] = '&#38306;&#25968;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnofunctions'] = '&#38306;&#25968;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateplfunction'] = 'SQL/PL &#38306;&#25968;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strcreateinternalfunction'] = '&#20869;&#37096;&#38306;&#25968;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strcreatecfunction'] = 'C &#38306;&#25968;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strfunctionname'] = '&#38306;&#25968;&#21517;';
	$lang['strreturns'] = '&#36820;&#12426;&#20516;';
	$lang['strarguments'] = '&#24341;&#25968;';
	$lang['strproglanguage'] = '&#12503;&#12525;&#12464;&#12521;&#12511;&#12531;&#12464;&#35328;&#35486;';
	$lang['strfunctionneedsname'] = '&#38306;&#25968;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strfunctionneedsdef'] = '&#38306;&#25968;&#12398;&#23450;&#32681;&#12434;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12354;&#12379;&#12435;&#12290;';
	$lang['strfunctioncreated'] = '&#38306;&#25968;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfunctioncreatedbad'] = '&#38306;&#25968;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropfunction'] = '&#26412;&#24403;&#12395;&#38306;&#25968;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strfunctiondropped'] = '&#38306;&#25968;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfunctiondroppedbad'] = '&#38306;&#25968;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfunctionupdated'] = '&#38306;&#25968;&#12434;&#26356;&#26032;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfunctionupdatedbad'] = '&#38306;&#25968;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strobjectfile'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12501;&#12449;&#12452;&#12523;';
	$lang['strlinksymbol'] = '&#12522;&#12531;&#12463;&#12471;&#12531;&#12508;&#12523;';

	// Triggers
	$lang['strtrigger'] = '&#12488;&#12522;&#12460;&#12540;';
	$lang['strtriggers'] = '&#12488;&#12522;&#12460;&#12540;';
	$lang['strshowalltriggers'] = '&#20840;&#12488;&#12522;&#12460;&#12540;&#12434;&#34920;&#31034;';
	$lang['strnotrigger'] = '&#12488;&#12522;&#12460;&#12540;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnotriggers'] = '&#12488;&#12522;&#12460;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatetrigger'] = '&#12488;&#12522;&#12460;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strtriggerneedsname'] = '&#12488;&#12522;&#12460;&#12540;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strtriggerneedsfunc'] = '&#12488;&#12522;&#12460;&#12540;&#12398;&#12383;&#12417;&#12398;&#38306;&#25968;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtriggercreated'] = '&#12488;&#12522;&#12460;&#12540;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtriggercreatedbad'] = '&#12488;&#12522;&#12460;&#12540;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroptrigger'] = '&#26412;&#24403;&#12395;&#12488;&#12522;&#12460;&#12540;&#12300;%s&#12301;&#12434;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12300;%s&#12301;&#12363;&#12425;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtriggerdropped'] = '&#12488;&#12522;&#12460;&#12540;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtriggerdroppedbad'] = '&#12488;&#12522;&#12460;&#12540;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtriggeraltered'] = '&#12488;&#12522;&#12460;&#12540;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtriggeralteredbad'] = '&#12488;&#12522;&#12460;&#12540;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
$lang['strforeach']  =  'For each';

	// Types
	$lang['strtype'] = '&#12487;&#12540;&#12479;&#22411;';
	$lang['strtypes'] = '&#12487;&#12540;&#12479;&#22411;';
	$lang['strshowalltypes'] = '&#20840;&#12487;&#12540;&#12479;&#22411;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnotype'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnotypes'] = '&#12487;&#12540;&#12479;&#22411;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
	$lang['strcreatetype'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strcreatecomptype'] = '&#35079;&#21512;&#22411;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strtypeneedsfield'] = '&#23569;&#12394;&#12367;&#12392;&#12418; 1 &#12388;&#12398;&#12501;&#12451;&#12540;&#12523;&#12489;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtypeneedscols'] = '&#26377;&#21177;&#12394;&#12501;&#12451;&#12540;&#12523;&#12489;&#12398;&#25968;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtypename'] = '&#12487;&#12540;&#12479;&#22411;&#21517;';
	$lang['strinputfn'] = '&#20837;&#21147;&#38306;&#25968;';
	$lang['stroutputfn'] = '&#20986;&#21147;&#38306;&#25968;';
$lang['strpassbyval'] = 'Passed by val?';
	$lang['stralignment'] = '&#12450;&#12521;&#12452;&#12513;&#12531;&#12488;';
	$lang['strelement'] = '&#35201;&#32032;';
	$lang['strdelimiter'] = '&#12487;&#12511;&#12522;&#12479;';
	$lang['strstorage'] = '&#12473;&#12488;&#12524;&#12540;&#12472;';
	$lang['strfield'] = '&#12501;&#12451;&#12540;&#12523;&#12489;';
	$lang['strnumfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#25968;';
	$lang['strtypeneedsname'] = '&#22411;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtypeneedslen'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#38263;&#12373;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strtypecreated'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtypecreatedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroptype'] = '&#26412;&#24403;&#12395;&#12487;&#12540;&#12479;&#22411;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtypedropped'] = '&#12487;&#12540;&#12479;&#22411;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtypedroppedbad'] = '&#12487;&#12540;&#12479;&#22411;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strflavor'] = '&#31278;&#39006;';
	$lang['strbasetype'] = '&#22522;&#26412;';
	$lang['strcompositetype'] = '&#35079;&#21512;&#22411;';
	$lang['strpseudotype'] = '&#25836;&#20284;&#12487;&#12540;&#12479;';

	// Schemas
	$lang['strschema'] = '&#12473;&#12461;&#12540;&#12510;';
	$lang['strschemas'] = '&#12473;&#12461;&#12540;&#12510;';
	$lang['strshowallschemas'] = '&#20840;&#12473;&#12461;&#12540;&#12510;&#12434;&#34920;&#31034;&#12377;&#12427;';
	$lang['strnoschema'] = '&#12473;&#12461;&#12540;&#12510;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnoschemas'] = '&#12473;&#12461;&#12540;&#12510;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateschema'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strschemaname'] = '&#12473;&#12461;&#12540;&#12510;&#21517;';
	$lang['strschemaneedsname'] = '&#12473;&#12461;&#12540;&#12510;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strschemacreated'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strschemacreatedbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropschema'] = '&#26412;&#24403;&#12395;&#12473;&#12461;&#12540;&#12510;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strschemadropped'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strschemadroppedbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strschemaaltered'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strschemaalteredbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsearchpath'] = '&#12473;&#12461;&#12540;&#12510;&#26908;&#32034;&#12497;&#12473;';

	// Reports
	$lang['strreport'] = '&#12524;&#12509;&#12540;&#12488;';
	$lang['strreports'] = '&#12524;&#12509;&#12540;&#12488;';
	$lang['strshowallreports'] = '&#20840;&#12524;&#12509;&#12540;&#12488;&#12434;&#35211;&#12427;';
	$lang['strnoreports'] = '&#12524;&#12509;&#12540;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatereport'] = '&#12524;&#12509;&#12540;&#12488;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strreportdropped'] = '&#12524;&#12509;&#12540;&#12488;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strreportdroppedbad'] = '&#12524;&#12509;&#12540;&#12488;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropreport'] = '&#26412;&#24403;&#12395;&#12524;&#12509;&#12540;&#12488;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strreportneedsname'] = '&#12524;&#12509;&#12540;&#12488;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strreportneedsdef'] = '&#12524;&#12509;&#12540;&#12488;&#29992;&#12398;SQL&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strreportcreated'] = '&#12524;&#12509;&#12540;&#12488;&#12398;&#20445;&#23384;&#12434;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strreportcreatedbad'] = '&#12524;&#12509;&#12540;&#12488;&#12398;&#20445;&#23384;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Domains
	$lang['strdomain'] = '&#12489;&#12513;&#12452;&#12531;';
	$lang['strdomains'] = '&#12489;&#12513;&#12452;&#12531;';
	$lang['strshowalldomains'] = '&#20840;&#12489;&#12513;&#12452;&#12531;&#12434;&#35211;&#12427;';
	$lang['strnodomains'] = '&#12489;&#12513;&#12452;&#12531;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatedomain'] = '&#12489;&#12513;&#12452;&#12531;&#20316;&#25104;';
	$lang['strdomaindropped'] = '&#12489;&#12513;&#12452;&#12531;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdomaindroppedbad'] = '&#12489;&#12513;&#12452;&#12531;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropdomain'] = '&#26412;&#24403;&#12395;&#12489;&#12513;&#12452;&#12531;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strdomainneedsname'] = '&#12489;&#12513;&#12452;&#12531;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strdomaincreated'] = '&#12489;&#12513;&#12452;&#12531;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdomaincreatedbad'] = '&#12489;&#12513;&#12452;&#12531;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';	
	$lang['strdomainaltered'] = '&#12489;&#12513;&#12452;&#12531;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strdomainalteredbad'] = '&#12489;&#12513;&#12452;&#12531;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';	

	// Operators
	$lang['stroperator'] = '&#28436;&#31639;&#23376;';
	$lang['stroperators'] = '&#28436;&#31639;&#23376;';
	$lang['strshowalloperators'] = '&#20840;&#28436;&#31639;&#23376;&#12434;&#35211;&#12427;';
	$lang['strnooperator'] = '&#28436;&#31639;&#23376;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strnooperators'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreateoperator'] = '&#28436;&#31639;&#23376;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strleftarg'] = '&#24038;&#24341;&#25968;&#12479;&#12452;&#12503;';
	$lang['strrightarg'] = '&#21491;&#24341;&#25968;&#12479;&#12452;&#12503;';
	$lang['strcommutator'] = '&#20132;&#20195;';
	$lang['strnegator'] = '&#21542;&#23450;';
	$lang['strrestrict'] = '&#21046;&#38480;';
	$lang['strjoin'] = '&#32080;&#21512;';
	$lang['strhashes'] = '&#12495;&#12483;&#12471;&#12517;';
	$lang['strmerges'] = '&#20341;&#21512;';
	$lang['strleftsort'] = '&#24038;&#12477;&#12540;&#12488;';
	$lang['strrightsort'] = '&#21491;&#12477;&#12540;&#12488;';
	$lang['strlessthan'] = '&#26410;&#28288;';
	$lang['strgreaterthan'] = '&#20197;&#19978;';
	$lang['stroperatorneedsname'] = '&#28436;&#31639;&#23376;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['stroperatorcreated'] = '&#28436;&#31639;&#23376;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['stroperatorcreatedbad'] = '&#28436;&#31639;&#23376;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropoperator'] = '&#26412;&#24403;&#12395;&#28436;&#31639;&#23376;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['stroperatordropped'] = '&#28436;&#31639;&#23376;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['stroperatordroppedbad'] = '&#28436;&#31639;&#23376;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Casts
	$lang['strcasts'] = '&#12461;&#12515;&#12473;&#12488;';
	$lang['strnocasts'] = '&#12461;&#12515;&#12473;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strsourcetype'] = '&#12477;&#12540;&#12473;&#12479;&#12452;&#12503;';
	$lang['strtargettype'] = '&#12479;&#12540;&#12466;&#12483;&#12488;&#12479;&#12452;&#12503;';
	$lang['strimplicit'] = '&#26263;&#40665;';
$lang['strinassignment'] = 'In assignment';
	$lang['strbinarycompat'] = '(&#12496;&#12452;&#12490;&#12522;&#20114;&#25563;)';
	
	// Conversions
	$lang['strconversions'] = '&#22793;&#25563;';
	$lang['strnoconversions'] = '&#22793;&#25563;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strsourceencoding'] = '&#22793;&#25563;&#20803;&#12456;&#12531;&#12467;&#12540;&#12489;';
	$lang['strtargetencoding'] = '&#22793;&#25563;&#20808;&#12456;&#12531;&#12467;&#12540;&#12489;';
	
	// Languages
	$lang['strlanguages'] = '&#35328;&#35486;';
	$lang['strnolanguages'] = '&#35328;&#35486;&#12364;&#23384;&#22312;&#12375;&#12414;&#12379;&#12435;&#12290;';
$lang['strtrusted'] = 'Trusted';
	
	// Info
	$lang['strnoinfo'] = '&#26377;&#21177;&#12394;&#24773;&#22577;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strreferringtables'] = '&#21442;&#29031;&#12486;&#12540;&#12502;&#12523;';
	$lang['strparenttables'] = '&#35242;&#12486;&#12540;&#12502;&#12523;';
	$lang['strchildtables'] = '&#23376;&#12486;&#12540;&#12502;&#12523;';

	// Aggregates
	$lang['straggregates'] = '&#38598;&#35336;';
	$lang['strnoaggregates'] = '&#38598;&#35336;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['stralltypes'] = '(&#20840;&#12390;&#12398;&#12479;&#12452;&#12503;)';

	// Operator Classes
	$lang['stropclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;';
	$lang['strnoopclasses'] = '&#28436;&#31639;&#23376;&#12463;&#12521;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['straccessmethod'] = '&#12450;&#12463;&#12475;&#12473;&#26041;&#27861;';

	// Stats and performance
	$lang['strrowperf'] = '&#34892;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
	$lang['strioperf'] = 'I/O &#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
	$lang['stridxrowperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#34892;&#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
	$lang['stridxioperf'] = '&#12452;&#12531;&#12487;&#12483;&#12463;&#12473; I/O &#12497;&#12501;&#12457;&#12540;&#12510;&#12531;&#12473;';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = '&#12471;&#12540;&#12465;&#12531;&#12471;&#12515;&#12523;';
	$lang['strscan'] = '&#26908;&#32034;';
	$lang['strread'] = '&#35501;&#36796;';
	$lang['strfetch'] = '&#21462;&#24471;';
	$lang['strheap'] = '&#12498;&#12540;&#12503;';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST &#12452;&#12531;&#12487;&#12483;&#12463;&#12473;';
	$lang['strcache'] = '&#12461;&#12515;&#12483;&#12471;&#12517;';
	$lang['strdisk'] = '&#12487;&#12451;&#12473;&#12463;';
	$lang['strrows2'] = '&#34892;';

	// Tablespaces
	$lang['strtablespace'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;';
	$lang['strtablespaces']  =  '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;';
	$lang['strshowalltablespaces'] = '&#12377;&#12409;&#12390;&#12398;&#12486;&#12540;&#12502;&#12523;&#12473;&#12506;&#12540;&#12473;&#12434;&#34920;&#31034;';
	$lang['strnotablespaces'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatetablespace'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strlocation'] = '&#12525;&#12465;&#12540;&#12471;&#12519;&#12531;';
	$lang['strtablespaceneedsname'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strtablespaceneedsloc'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#20316;&#25104;&#12434;&#12377;&#12427;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strtablespacecreated'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablespacecreatedbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroptablespace'] = '&#26412;&#24403;&#12395;&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtablespacedropped'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablespacedroppedbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablespacealtered'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtablespacealteredbad'] = '&#12486;&#12540;&#12502;&#12523;&#31354;&#38291;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Slony clusters
	$lang['strcluster']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;';
	$lang['strnoclusters']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strconfdropcluster']  =  '&#26412;&#24403;&#12395;&#12463;&#12521;&#12473;&#12479;&#12540;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strclusterdropped']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strclusterdroppedbad']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strinitcluster']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12434;&#21021;&#26399;&#21270;&#12377;&#12427;';
	$lang['strclustercreated']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12434;&#21021;&#26399;&#21270;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strclustercreatedbad']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12398;&#21021;&#26399;&#21270;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strclusterneedsname']  =  '&#12463;&#12521;&#12473;&#12479;&#12540;&#12398;&#21517;&#21069;&#12434;&#19982;&#12360;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strclusterneedsnodeid']  =  '&#12525;&#12540;&#12459;&#12523;&#12494;&#12540;&#12489;&#12398; ID &#12434;&#19982;&#12360;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	
	// Slony nodes
	$lang['strnodes']  =  'Nodes';
	$lang['strnonodes']  =  '&#12494;&#12540;&#12489;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatenode']  =  '&#12494;&#12540;&#12489;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strid']  =  'ID';
	$lang['stractive']  =  '&#12450;&#12463;&#12486;&#12451;&#12502;';
	$lang['strnodecreated']  =  '&#12494;&#12540;&#12489;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strnodecreatedbad']  =  '&#12494;&#12540;&#12489;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdropnode']  =  '&#26412;&#24403;&#12395;&#12494;&#12540;&#12489;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strnodedropped']  =  '&#12494;&#12540;&#12489;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strnodedroppedbad']  =  '&#12494;&#12540;&#12489;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strfailover']  =  '&#12501;&#12455;&#12452;&#12523;&#12458;&#12540;&#12496;&#12540;&#12377;&#12427;';
	$lang['strnodefailedover']  =  '&#12494;&#12540;&#12489;&#12434;&#12501;&#12455;&#12452;&#12523;&#12458;&#12540;&#12496;&#12540;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strnodefailedoverbad']  =  '&#12494;&#12540;&#12489;&#12398;&#12501;&#12455;&#12452;&#12523;&#12458;&#12540;&#12496;&#12540;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	
	// Slony paths	
	$lang['strpaths']  =  '&#12497;&#12473;';
	$lang['strnopaths']  =  '&#12497;&#12473;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatepath']  =  '&#12497;&#12473;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strnodename']  =  '&#12494;&#12540;&#12489;&#21517;';
	$lang['strnodeid']  =  '&#12494;&#12540;&#12489; ID';
	$lang['strconninfo']  =  '&#25509;&#32154;&#25991;&#23383;&#21015;';
	$lang['strconnretry']  =  '&#25509;&#32154;&#12398;&#20877;&#23455;&#34892;&#12414;&#12391;&#12398;&#31186;&#25968;';
	$lang['strpathneedsconninfo']  =  '&#12497;&#12473;&#12398;&#25509;&#32154;&#25991;&#23383;&#21015;&#12434;&#19982;&#12360;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strpathneedsconnretry']  =  '&#25509;&#32154;&#12398;&#20877;&#23455;&#34892;&#12414;&#12391;&#12398;&#31186;&#25968;&#12434;&#19982;&#12360;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
	$lang['strpathcreated']  =  '&#12497;&#12473;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strpathcreatedbad']  =  '&#12497;&#12473;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroppath']  =  '&#26412;&#24403;&#12395;&#12497;&#12473;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strpathdropped']  =  '&#12497;&#12473;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strpathdroppedbad']  =  '&#12497;&#12473;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Slony listens
	$lang['strlistens']  =  '&#12522;&#12483;&#12473;&#12531;';
	$lang['strnolistens']  =  '&#12522;&#12483;&#12473;&#12531;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreatelisten']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strlistencreated']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strlistencreatedbad']  =  '&#12522;&#12483;&#12473;&#12531;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroplisten']  =  '&#26412;&#24403;&#12395;&#12522;&#12483;&#12473;&#12531;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strlistendropped']  =  '&#12522;&#12483;&#12473;&#12531;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strlistendroppedbad']  =  '&#12522;&#12483;&#12473;&#12531;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Slony replication sets
	$lang['strrepsets']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;';
	$lang['strnorepsets']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strcreaterepset']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#20316;&#25104;&#12377;&#12427;';
	$lang['strrepsetcreated']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetcreatedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfdroprepset']  =  '&#26412;&#24403;&#12395;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strrepsetdropped']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetdroppedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strmerge']  =  '&#32113;&#21512;&#12377;&#12427;';
	$lang['strmergeinto']  =  '&#32113;&#21512;&#20808;';
	$lang['strrepsetmerged']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#32113;&#21512;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetmergedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#32113;&#21512;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strmove']  =  '&#31227;&#21205;&#12377;&#12427;';
	$lang['strneworigin']  =  '&#26032;&#35215;&#12458;&#12522;&#12472;&#12531;';
	$lang['strrepsetmoved']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#31227;&#21205;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetmovedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#31227;&#21205;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strnewrepset']  =  '&#26032;&#35215;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;';
	$lang['strlock']  =  '&#12525;&#12483;&#12463;';
	$lang['strlocked']  =  '&#12525;&#12483;&#12463;&#28168;';
	$lang['strunlock']  =  '&#12525;&#12483;&#12463;&#35299;&#38500;';
	$lang['strconflockrepset']  =  '&#26412;&#24403;&#12395;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12300;%s&#12301;&#12434;&#12525;&#12483;&#12463;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strrepsetlocked']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#12525;&#12483;&#12463;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetlockedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#12525;&#12483;&#12463;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfunlockrepset']  =  '&#26412;&#24403;&#12395;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12300;%s&#12301;&#12398;&#12525;&#12483;&#12463;&#12434;&#35299;&#38500;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strrepsetunlocked']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12434;&#35299;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strrepsetunlockedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12398;&#35299;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strexecute']  =  '&#23455;&#34892;&#12377;&#12427;';
	$lang['stronlyonnode']  =  '&#12494;&#12540;&#12489;&#12391;&#12398;&#12415;';
	$lang['strddlscript']  =  'DDL &#12473;&#12463;&#12522;&#12503;&#12488;';
	$lang['strscriptneedsbody']  =  '&#12377;&#12409;&#12390;&#12398;&#12494;&#12540;&#12489;&#19978;&#12391;&#23455;&#34892;&#12373;&#12428;&#12427;&#12473;&#12463;&#12522;&#12503;&#12488;&#12434;&#25552;&#20379;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
	$lang['strscriptexecuted']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12391; DDL &#12473;&#12463;&#12522;&#12503;&#12488;&#12434;&#23455;&#34892;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strscriptexecutedbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12391;&#12398; DDL &#12473;&#12463;&#12522;&#12503;&#12488;&#12398;&#23455;&#34892;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtabletriggerstoretain']  =  '&#27425;&#12398;&#12488;&#12522;&#12460;&#12540;&#12399; Slony &#12395;&#12424;&#12426;&#28961;&#21177;&#12395;&#12394;&#12425;&#12394;&#12356;&#12391;&#12375;&#12423;&#12358;:';

	// Slony tables in replication sets
	$lang['straddtable']  =  '&#12486;&#12540;&#12502;&#12523;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strtableneedsuniquekey']  =  '&#36861;&#21152;&#12373;&#12428;&#12427;&#12486;&#12540;&#12502;&#12523;&#12399;&#12503;&#12521;&#12452;&#12510;&#12522;&#12363;&#12518;&#12491;&#12540;&#12463;&#12461;&#12540;&#12434;&#35201;&#27714;&#12375;&#12414;&#12377;&#12290;';
	$lang['strtableaddedtorepset']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12395;&#12486;&#12540;&#12502;&#12523;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtableaddedtorepsetbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12408;&#12398;&#12486;&#12540;&#12502;&#12523;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfremovetablefromrepset']  =  '&#26412;&#24403;&#12395;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12300;%s&#12301;&#12363;&#12425;&#12486;&#12540;&#12502;&#12523;&#12300;%s&#12301;&#12434;&#21066;&#38500;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strtableremovedfromrepset']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12363;&#12425;&#12486;&#12540;&#12502;&#12523;&#12434;&#21066;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strtableremovedfromrepsetbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12363;&#12425;&#12486;&#12540;&#12502;&#12523;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Slony sequences in replication sets
	$lang['straddsequence']  =  '&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#36861;&#21152;&#12377;&#12427;';
	$lang['strsequenceaddedtorepset']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12395;&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#36861;&#21152;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequenceaddedtorepsetbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12408;&#12398;&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#36861;&#21152;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strconfremovesequencefromrepset']  =  '&#26412;&#24403;&#12395;&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12300;%s&#12301;&#12363;&#12425;&#12471;&#12540;&#12465;&#12531;&#12473;&#12300;%s&#12301;&#12434;&#21066;&#38500;&#12375;&#12414;&#12377;&#12363;?';
	$lang['strsequenceremovedfromrepset']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12363;&#12425;&#12471;&#12540;&#12465;&#12531;&#12473;&#12434;&#21066;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strsequenceremovedfromrepsetbad']  =  '&#12524;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12475;&#12483;&#12488;&#12363;&#12425;&#12471;&#12540;&#12465;&#12531;&#12473;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';

	// Slony subscriptions
	$lang['strsubscriptions']  =  '&#12469;&#12502;&#12473;&#12463;&#12522;&#12503;&#12471;&#12519;&#12531;';
	$lang['strnosubscriptions']  =  '&#12469;&#12502;&#12473;&#12463;&#12522;&#12503;&#12471;&#12519;&#12531;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';

	// Miscellaneous
	$lang['strtopbar'] = '&#12469;&#12540;&#12496;&#12540; %2$s &#12398;&#12509;&#12540;&#12488;&#30058;&#21495; %3$s &#12391;&#23455;&#34892;&#20013;&#12398; %1$s &#12395;&#25509;&#32154;&#20013; -- &#12518;&#12540;&#12470;&#12540;&#12300;%4$s&#12301;&#12392;&#12375;&#12390;&#12525;&#12464;&#12452;&#12531;&#20013;(%5$s)';
	$lang['strtimefmt'] = 'Y &#24180; n &#26376; j &#26085; G:i';
	$lang['strhelp'] = '&#12504;&#12523;&#12503;';
	$lang['strhelpicon'] = '?';
	$lang['strlogintitle'] = '%s &#12395;&#12525;&#12464;&#12452;&#12531;';
	$lang['strlogoutmsg'] = '%s &#12434;&#12525;&#12464;&#12450;&#12454;&#12488;&#12375;&#12414;&#12375;&#12383;&#12290;';
	$lang['strloading'] = '&#35501;&#12415;&#36796;&#12415;&#20013;...';
	$lang['strerrorloading'] = '&#35501;&#12415;&#36796;&#12415;&#20013;&#12398;&#12456;&#12521;&#12540;&#12391;&#12377;&#12290;';
	$lang['strclicktoreload'] = '&#12463;&#12522;&#12483;&#12463;&#12391;&#20877;&#35501;&#12415;&#36796;&#12415;';
?>
